==> timberas-0.2.0.tar.gz: timberas-0.2.0/docs/index.md <==
# About

*timberas* is a Python package developed to support research and design of Australian timber structures. It can be used to determine the section properties, materials properties, and design capacities for structural members as per Australian Standard AS1720.1:2020 (Timber Structures Part 1: Design Methods). 

*timberas* is developed by [Dr Joe Gattas](https://researchers.uq.edu.au/researcher/9443)  and research collaborators at the [University of Queensland](https://civil.uq.edu.au/) and [ARC Advance Timber Hub](https://www.advance-timber-hub.org/). 

# Contents
- [Installation](install.md)
- Tutorials
    - [Getting Started I](tutorial-1.md): Create timber sections and materials
    - [Getting Started II](tutorial-2.md) Create a timber member and solve member design capacities. 
- [API Reference](reference.md)


# Support
Please see the project Github repository and README file for the latest updates and issues. 

# License
*timberas* is provided under an MIT License. Please refer to the project Github repository and LICENSE file for more information. 


# Acknowledgements
This package has been developed from research projects supported by the [University of Queensland](https://civil.uq.edu.au/) and [ARC Future Timber Hub](https://futuretimberhub.org/).

If you use *timberas* for projects or scientific publications, please consider citing our journal paper:
> Jiang, J., Ottenhaus, L. M., & Gattas, J. M. (2023). A parametric design framework for timber framing span tables. *Australian Journal of Civil Engineering*, 1-16. [doi:10.1080/14488353.2023.2227432](https://doi.org/10.1080/14488353.2023.2227432).

## Contributors: 

- [Dr Joe Gattas](https://researchers.uq.edu.au/researcher/9443)
- Jian Jiang
- [Dr Lisa Ottenhaus](https://researchers.uq.edu.au/researcher/24484)

==> timberas-0.3.0.tar.gz: timberas-0.3.0/docs/index.md <==
# About

*timberas* is a Python package developed to support research and design of Australian timber structures. It can be used to determine the section properties, materials properties, and design capacities for structural members as per Australian Standard AS1720.1:2020 (Timber Structures Part 1: Design Methods). 

*timberas* is developed by [Dr Joe Gattas](https://researchers.uq.edu.au/researcher/9443)  and research collaborators at the [University of Queensland](https://civil.uq.edu.au/) and [ARC Advance Timber Hub](https://www.advance-timber-hub.org/). 

# Contents
- [Installation](install.md)
- Tutorials
    - [Quick Start](tutorial-1.md)
    - [Sections and Materials](tutorial-2.md)
    - [Tension and Compression Capacity](tutorial-3.md) 
    - [Bending and Shear Capacity](tutorial-4.md) 
- [API Reference](reference.md)


# Support
Please see the project [Github repository](https://github.com/Folded-Structures-Lab/timber-as) and README file for the latest updates and issues. 

# License
*timberas* is provided under an MIT License. Please refer to the project Github repository and LICENSE file for more information. 


# Acknowledgements
This package has been developed from research projects supported by the [University of Queensland](https://civil.uq.edu.au/) and [ARC Future Timber Hub](https://futuretimberhub.org/).

If you use *timberas* for projects or scientific publications, please consider citing our journal paper:
> Jiang, J., Ottenhaus, L. M., & Gattas, J. M. (2023). A parametric design framework for timber framing span tables. *Australian Journal of Civil Engineering*, 1-16. [doi:10.1080/14488353.2023.2227432](https://doi.org/10.1080/14488353.2023.2227432).

## Contributors: 

- [Dr Joe Gattas](https://researchers.uq.edu.au/researcher/9443)
- Jian Jiang
- [Dr Lisa Ottenhaus](https://researchers.uq.edu.au/researcher/24484)
